@@ -19,6 +19,7 @@ from typing import Any, Dict, Mapping, Sequence, Type, overload
 from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
+    ComponentDeploymentUpdateTypeType,
     DeploymentUpdateTypeType,
     EnvironmentAccountConnectionRequesterAccountTypeType,
     EnvironmentAccountConnectionStatusType,
@@ -28,6 +29,9 @@ from .literals import (
     TemplateVersionStatusType,
 )
 from .paginator import (
+    ListComponentOutputsPaginator,
+    ListComponentProvisionedResourcesPaginator,
+    ListComponentsPaginator,
     ListEnvironmentAccountConnectionsPaginator,
     ListEnvironmentOutputsPaginator,
     ListEnvironmentProvisionedResourcesPaginator,
@@ -48,10 +52,12 @@ from .paginator import (
 )
 from .type_defs import (
     AcceptEnvironmentAccountConnectionOutputTypeDef,
+    CancelComponentDeploymentOutputTypeDef,
     CancelEnvironmentDeploymentOutputTypeDef,
     CancelServiceInstanceDeploymentOutputTypeDef,
     CancelServicePipelineDeploymentOutputTypeDef,
     CompatibleEnvironmentTemplateInputTypeDef,
+    CreateComponentOutputTypeDef,
     CreateEnvironmentAccountConnectionOutputTypeDef,
     CreateEnvironmentOutputTypeDef,
     CreateEnvironmentTemplateOutputTypeDef,
@@ -61,6 +67,7 @@ from .type_defs import (
     CreateServiceTemplateOutputTypeDef,
     CreateServiceTemplateVersionOutputTypeDef,
     CreateTemplateSyncConfigOutputTypeDef,
+    DeleteComponentOutputTypeDef,
     DeleteEnvironmentAccountConnectionOutputTypeDef,
     DeleteEnvironmentOutputTypeDef,
     DeleteEnvironmentTemplateOutputTypeDef,
@@ -72,6 +79,7 @@ from .type_defs import (
     DeleteTemplateSyncConfigOutputTypeDef,
     EnvironmentTemplateFilterTypeDef,
     GetAccountSettingsOutputTypeDef,
+    GetComponentOutputTypeDef,
     GetEnvironmentAccountConnectionOutputTypeDef,
     GetEnvironmentOutputTypeDef,
     GetEnvironmentTemplateOutputTypeDef,
@@ -84,6 +92,9 @@ from .type_defs import (
     GetServiceTemplateVersionOutputTypeDef,
     GetTemplateSyncConfigOutputTypeDef,
     GetTemplateSyncStatusOutputTypeDef,
+    ListComponentOutputsOutputTypeDef,
+    ListComponentProvisionedResourcesOutputTypeDef,
+    ListComponentsOutputTypeDef,
     ListEnvironmentAccountConnectionsOutputTypeDef,
     ListEnvironmentOutputsOutputTypeDef,
     ListEnvironmentProvisionedResourcesOutputTypeDef,
@@ -107,6 +118,7 @@ from .type_defs import (
     TagTypeDef,
     TemplateVersionSourceInputTypeDef,
     UpdateAccountSettingsOutputTypeDef,
+    UpdateComponentOutputTypeDef,
     UpdateEnvironmentAccountConnectionOutputTypeDef,
     UpdateEnvironmentOutputTypeDef,
     UpdateEnvironmentTemplateOutputTypeDef,
@@ -119,6 +131,8 @@ from .type_defs import (
     UpdateTemplateSyncConfigOutputTypeDef,
 )
 from .waiter import (
+    ComponentDeletedWaiter,
+    ComponentDeployedWaiter,
     EnvironmentDeployedWaiter,
     EnvironmentTemplateVersionRegisteredWaiter,
     ServiceCreatedWaiter,
@@ -192,6 +206,17 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#can_paginate)
         """
 
+    def cancel_component_deployment(
+        self, *, componentName: str
+    ) -> CancelComponentDeploymentOutputTypeDef:
+        """
+        Attempts to cancel a component deployment (for a component that is in the
+        `IN_PROGRESS` deployment status).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.cancel_component_deployment)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#cancel_component_deployment)
+        """
+
     def cancel_environment_deployment(
         self, *, environmentName: str
     ) -> CancelEnvironmentDeploymentOutputTypeDef:
@@ -225,6 +250,26 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#cancel_service_pipeline_deployment)
         """
 
+    def create_component(
+        self,
+        *,
+        manifest: str,
+        name: str,
+        templateFile: str,
+        description: str = ...,
+        environmentName: str = ...,
+        serviceInstanceName: str = ...,
+        serviceName: str = ...,
+        serviceSpec: str = ...,
+        tags: Sequence[TagTypeDef] = ...
+    ) -> CreateComponentOutputTypeDef:
+        """
+        Create an Proton component.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.create_component)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#create_component)
+        """
+
     def create_environment(
         self,
         *,
@@ -232,11 +277,12 @@ class ProtonClient(BaseClient):
         spec: str,
         templateMajorVersion: str,
         templateName: str,
+        componentRoleArn: str = ...,
         description: str = ...,
         environmentAccountConnectionId: str = ...,
         protonServiceRoleArn: str = ...,
-        provisioningRepository: "RepositoryBranchInputTypeDef" = ...,
-        tags: Sequence["TagTypeDef"] = ...,
+        provisioningRepository: RepositoryBranchInputTypeDef = ...,
+        tags: Sequence[TagTypeDef] = ...,
         templateMinorVersion: str = ...
     ) -> CreateEnvironmentOutputTypeDef:
         """
@@ -253,7 +299,8 @@ class ProtonClient(BaseClient):
         managementAccountId: str,
         roleArn: str,
         clientToken: str = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        componentRoleArn: str = ...,
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateEnvironmentAccountConnectionOutputTypeDef:
         """
         Create an environment account connection in an environment account so that
@@ -272,7 +319,7 @@ class ProtonClient(BaseClient):
         displayName: str = ...,
         encryptionKey: str = ...,
         provisioning: Literal["CUSTOMER_MANAGED"] = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateEnvironmentTemplateOutputTypeDef:
         """
         Create an environment template for Proton.
@@ -284,12 +331,12 @@ class ProtonClient(BaseClient):
     def create_environment_template_version(
         self,
         *,
-        source: "TemplateVersionSourceInputTypeDef",
+        source: TemplateVersionSourceInputTypeDef,
         templateName: str,
         clientToken: str = ...,
         description: str = ...,
         majorVersion: str = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateEnvironmentTemplateVersionOutputTypeDef:
         """
         Create a new major or minor version of an environment template.
@@ -305,7 +352,7 @@ class ProtonClient(BaseClient):
         name: str,
         provider: RepositoryProviderType,
         encryptionKey: str = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateRepositoryOutputTypeDef:
         """
         Create and register a link to a repository that can be used with self-managed
@@ -326,7 +373,7 @@ class ProtonClient(BaseClient):
         description: str = ...,
         repositoryConnectionArn: str = ...,
         repositoryId: str = ...,
-        tags: Sequence["TagTypeDef"] = ...,
+        tags: Sequence[TagTypeDef] = ...,
         templateMinorVersion: str = ...
     ) -> CreateServiceOutputTypeDef:
         """
@@ -344,7 +391,7 @@ class ProtonClient(BaseClient):
         displayName: str = ...,
         encryptionKey: str = ...,
         pipelineProvisioning: Literal["CUSTOMER_MANAGED"] = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateServiceTemplateOutputTypeDef:
         """
         Create a service template.
@@ -356,13 +403,14 @@ class ProtonClient(BaseClient):
     def create_service_template_version(
         self,
         *,
-        compatibleEnvironmentTemplates: Sequence["CompatibleEnvironmentTemplateInputTypeDef"],
-        source: "TemplateVersionSourceInputTypeDef",
+        compatibleEnvironmentTemplates: Sequence[CompatibleEnvironmentTemplateInputTypeDef],
+        source: TemplateVersionSourceInputTypeDef,
         templateName: str,
         clientToken: str = ...,
         description: str = ...,
         majorVersion: str = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        supportedComponentSources: Sequence[Literal["DIRECTLY_DEFINED"]] = ...,
+        tags: Sequence[TagTypeDef] = ...
     ) -> CreateServiceTemplateVersionOutputTypeDef:
         """
         Create a new major or minor version of a service template.
@@ -388,6 +436,14 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#create_template_sync_config)
         """
 
+    def delete_component(self, *, name: str) -> DeleteComponentOutputTypeDef:
+        """
+        Delete an Proton component resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.delete_component)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#delete_component)
+        """
+
     def delete_environment(self, *, name: str) -> DeleteEnvironmentOutputTypeDef:
         """
         Delete an environment.
@@ -438,7 +494,7 @@ class ProtonClient(BaseClient):
 
     def delete_service(self, *, name: str) -> DeleteServiceOutputTypeDef:
         """
-        Delete a service.
+        Delete a service, with its instances and pipeline.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.delete_service)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#delete_service)
@@ -496,9 +552,17 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_account_settings)
         """
 
+    def get_component(self, *, name: str) -> GetComponentOutputTypeDef:
+        """
+        Get detailed data for a component.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_component)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_component)
+        """
+
     def get_environment(self, *, name: str) -> GetEnvironmentOutputTypeDef:
         """
-        Get detail data for an environment.
+        Get detailed data for an environment.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_environment)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_environment)
@@ -508,7 +572,7 @@ class ProtonClient(BaseClient):
         self, *, id: str
     ) -> GetEnvironmentAccountConnectionOutputTypeDef:
         """
-        In an environment account, view the detail data for an environment account
+        In an environment account, get the detailed data for an environment account
         connection.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_environment_account_connection)
@@ -517,7 +581,7 @@ class ProtonClient(BaseClient):
 
     def get_environment_template(self, *, name: str) -> GetEnvironmentTemplateOutputTypeDef:
         """
-        Get detail data for an environment template.
+        Get detailed data for an environment template.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_environment_template)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_environment_template)
@@ -527,7 +591,7 @@ class ProtonClient(BaseClient):
         self, *, majorVersion: str, minorVersion: str, templateName: str
     ) -> GetEnvironmentTemplateVersionOutputTypeDef:
         """
-        View detail data for a major or minor version of an environment template.
+        Get detailed data for a major or minor version of an environment template.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_environment_template_version)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_environment_template_version)
@@ -560,7 +624,7 @@ class ProtonClient(BaseClient):
 
     def get_service(self, *, name: str) -> GetServiceOutputTypeDef:
         """
-        Get detail data for a service.
+        Get detailed data for a service.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_service)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_service)
@@ -570,7 +634,7 @@ class ProtonClient(BaseClient):
         self, *, name: str, serviceName: str
     ) -> GetServiceInstanceOutputTypeDef:
         """
-        Get detail data for a service instance.
+        Get detailed data for a service instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_service_instance)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_service_instance)
@@ -578,7 +642,7 @@ class ProtonClient(BaseClient):
 
     def get_service_template(self, *, name: str) -> GetServiceTemplateOutputTypeDef:
         """
-        Get detail data for a service template.
+        Get detailed data for a service template.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_service_template)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_service_template)
@@ -588,7 +652,7 @@ class ProtonClient(BaseClient):
         self, *, majorVersion: str, minorVersion: str, templateName: str
     ) -> GetServiceTemplateVersionOutputTypeDef:
         """
-        View detail data for a major or minor version of a service template.
+        Get detailed data for a major or minor version of a service template.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_service_template_version)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_service_template_version)
@@ -614,6 +678,42 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_template_sync_status)
         """
 
+    def list_component_outputs(
+        self, *, componentName: str, nextToken: str = ...
+    ) -> ListComponentOutputsOutputTypeDef:
+        """
+        Get a list of component Infrastructure as Code (IaC) outputs.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.list_component_outputs)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#list_component_outputs)
+        """
+
+    def list_component_provisioned_resources(
+        self, *, componentName: str, nextToken: str = ...
+    ) -> ListComponentProvisionedResourcesOutputTypeDef:
+        """
+        List provisioned resources for a component with details.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.list_component_provisioned_resources)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#list_component_provisioned_resources)
+        """
+
+    def list_components(
+        self,
+        *,
+        environmentName: str = ...,
+        maxResults: int = ...,
+        nextToken: str = ...,
+        serviceInstanceName: str = ...,
+        serviceName: str = ...
+    ) -> ListComponentsOutputTypeDef:
+        """
+        List components with summary data.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.list_components)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#list_components)
+        """
+
     def list_environment_account_connections(
         self,
         *,
@@ -678,7 +778,7 @@ class ProtonClient(BaseClient):
     def list_environments(
         self,
         *,
-        environmentTemplates: Sequence["EnvironmentTemplateFilterTypeDef"] = ...,
+        environmentTemplates: Sequence[EnvironmentTemplateFilterTypeDef] = ...,
         maxResults: int = ...,
         nextToken: str = ...
     ) -> ListEnvironmentsOutputTypeDef:
@@ -718,7 +818,7 @@ class ProtonClient(BaseClient):
         self, *, serviceInstanceName: str, serviceName: str, nextToken: str = ...
     ) -> ListServiceInstanceOutputsOutputTypeDef:
         """
-        View a list service instance infrastructure as code outputs with detail data.
+        Get a list service of instance Infrastructure as Code (IaC) outputs.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.list_service_instance_outputs)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#list_service_instance_outputs)
@@ -738,7 +838,7 @@ class ProtonClient(BaseClient):
         self, *, maxResults: int = ..., nextToken: str = ..., serviceName: str = ...
     ) -> ListServiceInstancesOutputTypeDef:
         """
-        List service instances with summaries of detail data.
+        List service instances with summary data.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.list_service_instances)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#list_service_instances)
@@ -748,7 +848,7 @@ class ProtonClient(BaseClient):
         self, *, serviceName: str, nextToken: str = ...
     ) -> ListServicePipelineOutputsOutputTypeDef:
         """
-        View a list service pipeline infrastructure as code outputs with detail.
+        Get a list of service pipeline Infrastructure as Code (IaC) outputs.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.list_service_pipeline_outputs)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#list_service_pipeline_outputs)
@@ -815,7 +915,7 @@ class ProtonClient(BaseClient):
         resourceArn: str,
         status: ResourceDeploymentStatusType,
         deploymentId: str = ...,
-        outputs: Sequence["OutputTypeDef"] = ...,
+        outputs: Sequence[OutputTypeDef] = ...,
         statusMessage: str = ...
     ) -> Dict[str, Any]:
         """
@@ -837,7 +937,7 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#reject_environment_account_connection)
         """
 
-    def tag_resource(self, *, resourceArn: str, tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Tag a resource.
 
@@ -856,7 +956,7 @@ class ProtonClient(BaseClient):
     def update_account_settings(
         self,
         *,
-        pipelineProvisioningRepository: "RepositoryBranchInputTypeDef" = ...,
+        pipelineProvisioningRepository: RepositoryBranchInputTypeDef = ...,
         pipelineServiceRoleArn: str = ...
     ) -> UpdateAccountSettingsOutputTypeDef:
         """
@@ -866,15 +966,34 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#update_account_settings)
         """
 
+    def update_component(
+        self,
+        *,
+        deploymentType: ComponentDeploymentUpdateTypeType,
+        name: str,
+        description: str = ...,
+        serviceInstanceName: str = ...,
+        serviceName: str = ...,
+        serviceSpec: str = ...,
+        templateFile: str = ...
+    ) -> UpdateComponentOutputTypeDef:
+        """
+        Update a component.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.update_component)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#update_component)
+        """
+
     def update_environment(
         self,
         *,
         deploymentType: DeploymentUpdateTypeType,
         name: str,
+        componentRoleArn: str = ...,
         description: str = ...,
         environmentAccountConnectionId: str = ...,
         protonServiceRoleArn: str = ...,
-        provisioningRepository: "RepositoryBranchInputTypeDef" = ...,
+        provisioningRepository: RepositoryBranchInputTypeDef = ...,
         spec: str = ...,
         templateMajorVersion: str = ...,
         templateMinorVersion: str = ...
@@ -887,7 +1006,7 @@ class ProtonClient(BaseClient):
         """
 
     def update_environment_account_connection(
-        self, *, id: str, roleArn: str
+        self, *, id: str, componentRoleArn: str = ..., roleArn: str = ...
     ) -> UpdateEnvironmentAccountConnectionOutputTypeDef:
         """
         In an environment account, update an environment account connection to use a new
@@ -982,9 +1101,10 @@ class ProtonClient(BaseClient):
         majorVersion: str,
         minorVersion: str,
         templateName: str,
-        compatibleEnvironmentTemplates: Sequence["CompatibleEnvironmentTemplateInputTypeDef"] = ...,
+        compatibleEnvironmentTemplates: Sequence[CompatibleEnvironmentTemplateInputTypeDef] = ...,
         description: str = ...,
-        status: TemplateVersionStatusType = ...
+        status: TemplateVersionStatusType = ...,
+        supportedComponentSources: Sequence[Literal["DIRECTLY_DEFINED"]] = ...
     ) -> UpdateServiceTemplateVersionOutputTypeDef:
         """
         Update a major or minor version of a service template.
@@ -1011,6 +1131,31 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#update_template_sync_config)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_component_outputs"]
+    ) -> ListComponentOutputsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_paginator)
+        """
+
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_component_provisioned_resources"]
+    ) -> ListComponentProvisionedResourcesPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_paginator)
+        """
+
+    @overload
+    def get_paginator(self, operation_name: Literal["list_components"]) -> ListComponentsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_environment_account_connections"]
@@ -1162,6 +1307,20 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_paginator)
         """
 
+    @overload
+    def get_waiter(self, waiter_name: Literal["component_deleted"]) -> ComponentDeletedWaiter:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_waiter)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_waiter)
+        """
+
+    @overload
+    def get_waiter(self, waiter_name: Literal["component_deployed"]) -> ComponentDeployedWaiter:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_waiter)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_waiter)
+        """
+
     @overload
     def get_waiter(self, waiter_name: Literal["environment_deployed"]) -> EnvironmentDeployedWaiter:
         """
