@@ -6,9 +6,9 @@ Type annotations for proton service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_proton.literals import DeploymentStatusType
+    from mypy_boto3_proton.literals import ComponentDeletedWaiterName
 
-    data: DeploymentStatusType = "CANCELLED"
+    data: ComponentDeletedWaiterName = "component_deleted"
     ```
 """
 import sys
@@ -20,12 +20,18 @@ else:
 
 
 __all__ = (
+    "ComponentDeletedWaiterName",
+    "ComponentDeployedWaiterName",
+    "ComponentDeploymentUpdateTypeType",
     "DeploymentStatusType",
     "DeploymentUpdateTypeType",
     "EnvironmentAccountConnectionRequesterAccountTypeType",
     "EnvironmentAccountConnectionStatusType",
     "EnvironmentDeployedWaiterName",
     "EnvironmentTemplateVersionRegisteredWaiterName",
+    "ListComponentOutputsPaginatorName",
+    "ListComponentProvisionedResourcesPaginatorName",
+    "ListComponentsPaginatorName",
     "ListEnvironmentAccountConnectionsPaginatorName",
     "ListEnvironmentOutputsPaginatorName",
     "ListEnvironmentProvisionedResourcesPaginatorName",
@@ -54,6 +60,7 @@ __all__ = (
     "ServiceInstanceDeployedWaiterName",
     "ServicePipelineDeployedWaiterName",
     "ServiceStatusType",
+    "ServiceTemplateSupportedComponentSourceTypeType",
     "ServiceTemplateVersionRegisteredWaiterName",
     "ServiceUpdatedWaiterName",
     "SyncTypeType",
@@ -64,9 +71,13 @@ __all__ = (
     "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
+    "RegionName",
 )
 
 
+ComponentDeletedWaiterName = Literal["component_deleted"]
+ComponentDeployedWaiterName = Literal["component_deployed"]
+ComponentDeploymentUpdateTypeType = Literal["CURRENT_VERSION", "NONE"]
 DeploymentStatusType = Literal[
     "CANCELLED",
     "CANCELLING",
@@ -84,6 +95,9 @@ EnvironmentAccountConnectionRequesterAccountTypeType = Literal[
 EnvironmentAccountConnectionStatusType = Literal["CONNECTED", "PENDING", "REJECTED"]
 EnvironmentDeployedWaiterName = Literal["environment_deployed"]
 EnvironmentTemplateVersionRegisteredWaiterName = Literal["environment_template_version_registered"]
+ListComponentOutputsPaginatorName = Literal["list_component_outputs"]
+ListComponentProvisionedResourcesPaginatorName = Literal["list_component_provisioned_resources"]
+ListComponentsPaginatorName = Literal["list_components"]
 ListEnvironmentAccountConnectionsPaginatorName = Literal["list_environment_account_connections"]
 ListEnvironmentOutputsPaginatorName = Literal["list_environment_outputs"]
 ListEnvironmentProvisionedResourcesPaginatorName = Literal["list_environment_provisioned_resources"]
@@ -131,6 +145,7 @@ ServiceStatusType = Literal[
     "UPDATE_FAILED_CLEANUP_IN_PROGRESS",
     "UPDATE_IN_PROGRESS",
 ]
+ServiceTemplateSupportedComponentSourceTypeType = Literal["DIRECTLY_DEFINED"]
 ServiceTemplateVersionRegisteredWaiterName = Literal["service_template_version_registered"]
 ServiceUpdatedWaiterName = Literal["service_updated"]
 SyncTypeType = Literal["TEMPLATE_SYNC"]
@@ -245,6 +260,7 @@ ServiceName = Literal[
     "elbv2",
     "emr",
     "emr-containers",
+    "emr-serverless",
     "es",
     "events",
     "evidently",
@@ -459,6 +475,9 @@ ResourceServiceName = Literal[
     "sqs",
 ]
 PaginatorName = Literal[
+    "list_component_outputs",
+    "list_component_provisioned_resources",
+    "list_components",
     "list_environment_account_connections",
     "list_environment_outputs",
     "list_environment_provisioned_resources",
@@ -478,6 +497,8 @@ PaginatorName = Literal[
     "list_tags_for_resource",
 ]
 WaiterName = Literal[
+    "component_deleted",
+    "component_deployed",
     "environment_deployed",
     "environment_template_version_registered",
     "service_created",
@@ -487,3 +508,4 @@ WaiterName = Literal[
     "service_template_version_registered",
     "service_updated",
 ]
+RegionName = Literal["ap-northeast-1", "eu-west-1", "us-east-1", "us-east-2", "us-west-2"]
