@@ -10,6 +10,9 @@ Usage::
 
     from mypy_boto3_proton.client import ProtonClient
     from mypy_boto3_proton.paginator import (
+        ListComponentOutputsPaginator,
+        ListComponentProvisionedResourcesPaginator,
+        ListComponentsPaginator,
         ListEnvironmentAccountConnectionsPaginator,
         ListEnvironmentOutputsPaginator,
         ListEnvironmentProvisionedResourcesPaginator,
@@ -32,6 +35,9 @@ Usage::
     session = Session()
     client: ProtonClient = session.client("proton")
 
+    list_component_outputs_paginator: ListComponentOutputsPaginator = client.get_paginator("list_component_outputs")
+    list_component_provisioned_resources_paginator: ListComponentProvisionedResourcesPaginator = client.get_paginator("list_component_provisioned_resources")
+    list_components_paginator: ListComponentsPaginator = client.get_paginator("list_components")
     list_environment_account_connections_paginator: ListEnvironmentAccountConnectionsPaginator = client.get_paginator("list_environment_account_connections")
     list_environment_outputs_paginator: ListEnvironmentOutputsPaginator = client.get_paginator("list_environment_outputs")
     list_environment_provisioned_resources_paginator: ListEnvironmentProvisionedResourcesPaginator = client.get_paginator("list_environment_provisioned_resources")
@@ -64,6 +70,9 @@ from .literals import (
 )
 from .type_defs import (
     EnvironmentTemplateFilterTypeDef,
+    ListComponentOutputsOutputTypeDef,
+    ListComponentProvisionedResourcesOutputTypeDef,
+    ListComponentsOutputTypeDef,
     ListEnvironmentAccountConnectionsOutputTypeDef,
     ListEnvironmentOutputsOutputTypeDef,
     ListEnvironmentProvisionedResourcesOutputTypeDef,
@@ -91,6 +100,9 @@ else:
 
 
 __all__ = (
+    "ListComponentOutputsPaginator",
+    "ListComponentProvisionedResourcesPaginator",
+    "ListComponentsPaginator",
     "ListEnvironmentAccountConnectionsPaginator",
     "ListEnvironmentOutputsPaginator",
     "ListEnvironmentProvisionedResourcesPaginator",
@@ -121,6 +133,56 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
+class ListComponentOutputsPaginator(Boto3Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListComponentOutputs)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listcomponentoutputspaginator)
+    """
+
+    def paginate(
+        self, *, componentName: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListComponentOutputsOutputTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListComponentOutputs.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listcomponentoutputspaginator)
+        """
+
+
+class ListComponentProvisionedResourcesPaginator(Boto3Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListComponentProvisionedResources)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listcomponentprovisionedresourcespaginator)
+    """
+
+    def paginate(
+        self, *, componentName: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListComponentProvisionedResourcesOutputTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListComponentProvisionedResources.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listcomponentprovisionedresourcespaginator)
+        """
+
+
+class ListComponentsPaginator(Boto3Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListComponents)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listcomponentspaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        environmentName: str = ...,
+        serviceInstanceName: str = ...,
+        serviceName: str = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListComponentsOutputTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListComponents.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/paginators/#listcomponentspaginator)
+        """
+
+
 class ListEnvironmentAccountConnectionsPaginator(Boto3Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListEnvironmentAccountConnections)
@@ -133,7 +195,7 @@ class ListEnvironmentAccountConnectionsPaginator(Boto3Paginator):
         requestedBy: EnvironmentAccountConnectionRequesterAccountTypeType,
         environmentName: str = ...,
         statuses: Sequence[EnvironmentAccountConnectionStatusType] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListEnvironmentAccountConnectionsOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListEnvironmentAccountConnections.paginate)
@@ -148,7 +210,7 @@ class ListEnvironmentOutputsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, environmentName: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, environmentName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListEnvironmentOutputsOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListEnvironmentOutputs.paginate)
@@ -163,7 +225,7 @@ class ListEnvironmentProvisionedResourcesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, environmentName: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, environmentName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListEnvironmentProvisionedResourcesOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListEnvironmentProvisionedResources.paginate)
@@ -182,7 +244,7 @@ class ListEnvironmentTemplateVersionsPaginator(Boto3Paginator):
         *,
         templateName: str,
         majorVersion: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListEnvironmentTemplateVersionsOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListEnvironmentTemplateVersions.paginate)
@@ -197,7 +259,7 @@ class ListEnvironmentTemplatesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListEnvironmentTemplatesOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListEnvironmentTemplates.paginate)
@@ -214,8 +276,8 @@ class ListEnvironmentsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        environmentTemplates: Sequence["EnvironmentTemplateFilterTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        environmentTemplates: Sequence[EnvironmentTemplateFilterTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListEnvironmentsOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListEnvironments.paginate)
@@ -230,7 +292,7 @@ class ListRepositoriesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRepositoriesOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListRepositories.paginate)
@@ -250,7 +312,7 @@ class ListRepositorySyncDefinitionsPaginator(Boto3Paginator):
         repositoryName: str,
         repositoryProvider: RepositoryProviderType,
         syncType: Literal["TEMPLATE_SYNC"],
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRepositorySyncDefinitionsOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListRepositorySyncDefinitions.paginate)
@@ -269,7 +331,7 @@ class ListServiceInstanceOutputsPaginator(Boto3Paginator):
         *,
         serviceInstanceName: str,
         serviceName: str,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListServiceInstanceOutputsOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServiceInstanceOutputs.paginate)
@@ -288,7 +350,7 @@ class ListServiceInstanceProvisionedResourcesPaginator(Boto3Paginator):
         *,
         serviceInstanceName: str,
         serviceName: str,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListServiceInstanceProvisionedResourcesOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServiceInstanceProvisionedResources.paginate)
@@ -303,7 +365,7 @@ class ListServiceInstancesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, serviceName: str = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, serviceName: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListServiceInstancesOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServiceInstances.paginate)
@@ -318,7 +380,7 @@ class ListServicePipelineOutputsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, serviceName: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, serviceName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListServicePipelineOutputsOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServicePipelineOutputs.paginate)
@@ -333,7 +395,7 @@ class ListServicePipelineProvisionedResourcesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, serviceName: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, serviceName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListServicePipelineProvisionedResourcesOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServicePipelineProvisionedResources.paginate)
@@ -352,7 +414,7 @@ class ListServiceTemplateVersionsPaginator(Boto3Paginator):
         *,
         templateName: str,
         majorVersion: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListServiceTemplateVersionsOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServiceTemplateVersions.paginate)
@@ -367,7 +429,7 @@ class ListServiceTemplatesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListServiceTemplatesOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServiceTemplates.paginate)
@@ -382,7 +444,7 @@ class ListServicesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListServicesOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServices.paginate)
@@ -397,7 +459,7 @@ class ListTagsForResourcePaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, resourceArn: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, resourceArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTagsForResourceOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListTagsForResource.paginate)
