@@ -10,6 +10,8 @@ Usage::
 
     from mypy_boto3_proton.client import ProtonClient
     from mypy_boto3_proton.waiter import (
+        ComponentDeletedWaiter,
+        ComponentDeployedWaiter,
         EnvironmentDeployedWaiter,
         EnvironmentTemplateVersionRegisteredWaiter,
         ServiceCreatedWaiter,
@@ -23,6 +25,8 @@ Usage::
     session = Session()
     client: ProtonClient = session.client("proton")
 
+    component_deleted_waiter: ComponentDeletedWaiter = client.get_waiter("component_deleted")
+    component_deployed_waiter: ComponentDeployedWaiter = client.get_waiter("component_deployed")
     environment_deployed_waiter: EnvironmentDeployedWaiter = client.get_waiter("environment_deployed")
     environment_template_version_registered_waiter: EnvironmentTemplateVersionRegisteredWaiter = client.get_waiter("environment_template_version_registered")
     service_created_waiter: ServiceCreatedWaiter = client.get_waiter("service_created")
@@ -38,6 +42,8 @@ from botocore.waiter import Waiter as Boto3Waiter
 from .type_defs import WaiterConfigTypeDef
 
 __all__ = (
+    "ComponentDeletedWaiter",
+    "ComponentDeployedWaiter",
     "EnvironmentDeployedWaiter",
     "EnvironmentTemplateVersionRegisteredWaiter",
     "ServiceCreatedWaiter",
@@ -49,13 +55,39 @@ __all__ = (
 )
 
 
+class ComponentDeletedWaiter(Boto3Waiter):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ComponentDeleted)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#componentdeletedwaiter)
+    """
+
+    def wait(self, *, name: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ComponentDeleted.wait)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#componentdeletedwaiter)
+        """
+
+
+class ComponentDeployedWaiter(Boto3Waiter):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ComponentDeployed)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#componentdeployedwaiter)
+    """
+
+    def wait(self, *, name: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ComponentDeployed.wait)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#componentdeployedwaiter)
+        """
+
+
 class EnvironmentDeployedWaiter(Boto3Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.EnvironmentDeployed)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#environmentdeployedwaiter)
     """
 
-    def wait(self, *, name: str, WaiterConfig: "WaiterConfigTypeDef" = ...) -> None:
+    def wait(self, *, name: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.EnvironmentDeployed.wait)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#environmentdeployedwaiter)
@@ -74,7 +106,7 @@ class EnvironmentTemplateVersionRegisteredWaiter(Boto3Waiter):
         majorVersion: str,
         minorVersion: str,
         templateName: str,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.EnvironmentTemplateVersionRegistered.wait)
@@ -88,7 +120,7 @@ class ServiceCreatedWaiter(Boto3Waiter):
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#servicecreatedwaiter)
     """
 
-    def wait(self, *, name: str, WaiterConfig: "WaiterConfigTypeDef" = ...) -> None:
+    def wait(self, *, name: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ServiceCreated.wait)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#servicecreatedwaiter)
@@ -101,7 +133,7 @@ class ServiceDeletedWaiter(Boto3Waiter):
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#servicedeletedwaiter)
     """
 
-    def wait(self, *, name: str, WaiterConfig: "WaiterConfigTypeDef" = ...) -> None:
+    def wait(self, *, name: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ServiceDeleted.wait)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#servicedeletedwaiter)
@@ -114,9 +146,7 @@ class ServiceInstanceDeployedWaiter(Boto3Waiter):
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#serviceinstancedeployedwaiter)
     """
 
-    def wait(
-        self, *, name: str, serviceName: str, WaiterConfig: "WaiterConfigTypeDef" = ...
-    ) -> None:
+    def wait(self, *, name: str, serviceName: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ServiceInstanceDeployed.wait)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#serviceinstancedeployedwaiter)
@@ -129,7 +159,7 @@ class ServicePipelineDeployedWaiter(Boto3Waiter):
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#servicepipelinedeployedwaiter)
     """
 
-    def wait(self, *, name: str, WaiterConfig: "WaiterConfigTypeDef" = ...) -> None:
+    def wait(self, *, name: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ServicePipelineDeployed.wait)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#servicepipelinedeployedwaiter)
@@ -148,7 +178,7 @@ class ServiceTemplateVersionRegisteredWaiter(Boto3Waiter):
         majorVersion: str,
         minorVersion: str,
         templateName: str,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ServiceTemplateVersionRegistered.wait)
@@ -162,7 +192,7 @@ class ServiceUpdatedWaiter(Boto3Waiter):
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#serviceupdatedwaiter)
     """
 
-    def wait(self, *, name: str, WaiterConfig: "WaiterConfigTypeDef" = ...) -> None:
+    def wait(self, *, name: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Waiter.ServiceUpdated.wait)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/waiters/#serviceupdatedwaiter)
